Module error

Module error 

Error types for mcpls-core.

This module defines the canonical error type for the library, following the Microsoft Rust Guidelines for error handling.

Structs

ServerSpawnFailure
Details of a single server spawn failure.

Enums

Error
The main error type for mcpls-core operations.
McpErrorKind
JSON-RPC error-code classification for an Error, returned by Error::mcp_error_kind.

Constants

SERVER_INITIALIZING_ERROR_CODE
Bespoke JSON-RPC code for Error::ServerInitializing.
STATELESS_SUBSCRIPTION_ERROR_CODE
Bespoke JSON-RPC code for a resource subscription request rejected because it was served over rmcp’s stateless per-request HTTP path (#482).
WORKSPACE_INDEXING_ERROR_CODE
Bespoke JSON-RPC code for Error::WorkspaceIndexing.

Type Aliases

Result
A specialized Result type for mcpls-core operations.