Error types for mcpls-core.
This module defines the canonical error type for the library, following the Microsoft Rust Guidelines for error handling.
Structs
- Server
Spawn Failure - Details of a single server spawn failure.
Enums
- Error
- The main error type for mcpls-core operations.
- McpError
Kind - JSON-RPC error-code classification for an
Error, returned byError::mcp_error_kind.
Constants
- SERVER_
INITIALIZING_ ERROR_ CODE - Bespoke JSON-RPC code for
Error::ServerInitializing. - STATELESS_
SUBSCRIPTION_ ERROR_ CODE - Bespoke JSON-RPC code for a resource subscription request rejected because it was served over rmcp’s stateless per-request HTTP path (#482).
- WORKSPACE_
INDEXING_ ERROR_ CODE - Bespoke JSON-RPC code for
Error::WorkspaceIndexing.
Type Aliases
- Result
- A specialized Result type for mcpls-core operations.